@@ -118,6 +118,10 @@ class DfaClient(Client):
     if headers is None:
       self._headers = self.__LoadAuthCredentials()
     else:
+      # Pass app_name from config as appName to headers if still present
+      if self._config.get('app_name', None):
+        headers['appName'] = self._config['app_name']
+
       if Utils.BoolTypeConvert(self._config['strict']):
         SanityCheck.ValidateRequiredHeaders(headers, REQUIRED_SOAP_HEADERS)
       self._headers = headers
